# pdfsplitter
> A simple way to extract and parse images for machine learning workflows.


This file will become your README and also the index of your documentation.

```python
%load_ext autoreload
%autoreload 2
```

## Install

`pip install pdfsplitter`

## How to use

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


